@@ -38,12 +38,12 @@ public:
         : std::runtime_error(what.toStdString()) {}
 };
 
-Device::Device(QObject *parent)
-    : QObject(parent)
+Device::Device()
+    : QObject()
 {}
 
-Device::Device(const QDBusObjectPath &path, QObject *parent)
-    : QObject(parent)
+Device::Device(const QDBusObjectPath &path)
+    : QObject()
     , mInterface(std::make_unique<DeviceInterface>(
         DBusHelper::serviceName(), path.path(), DBusHelper::connection()))
     , mDBusPath(path)
@@ -60,10 +60,10 @@ Device::Device(const QDBusObjectPath &path, QObject *parent)
 
 Device::~Device() = default;
 
-QSharedPointer<Device> Device::create(const QDBusObjectPath &path, QObject *parent)
+QSharedPointer<Device> Device::create(const QDBusObjectPath &path)
 {
     try {
-        return QSharedPointer<Device>::create(path, parent);
+        return QSharedPointer<Device>::create(path);
     } catch (const DBusException &e) {
         qCWarning(log_libkbolt, "%s", e.what());
         return {};
@@ -138,13 +138,13 @@ QString Device::sysfsPath() const
 QDateTime Device::connectTime() const
 {
     const auto val = mInterface->connectTime();
-    return val == 0 ? QDateTime() : QDateTime::fromTime_t(val);
+    return val == 0 ? QDateTime() : QDateTime::fromSecsSinceEpoch(val);
 }
 
 QDateTime Device::authorizeTime() const
 {
     const auto val = mInterface->authorizeTime();
-    return val == 0 ? QDateTime() : QDateTime::fromTime_t(val);
+    return val == 0 ? QDateTime() : QDateTime::fromSecsSinceEpoch(val);
 }
 
 bool Device::stored() const
@@ -167,7 +167,7 @@ KeyState Device::keyState() const
 QDateTime Device::storeTime() const
 {
     const auto val = mInterface->storeTime();
-    return val == 0 ? QDateTime() : QDateTime::fromTime_t(val);
+    return val == 0 ? QDateTime() : QDateTime::fromSecsSinceEpoch(val);
 }
 
 QString Device::label() const
